@@ -8,7 +8,8 @@ class UserStates(StatesGroup):
     frequency_post = State()
     in_work = State()
     normal_start = State()
-    parse_start = State()
+    parsed_start = State()
+    parsing = State()
     set_pause = State()
 
 
